pub enum PeerSetRequest {
MostPoWSeen,
PeersWithMorePoW(u128),
StemPeer,
}Expand description
A request to the peer-set.
Variants
MostPoWSeen
The most claimed proof-of-work from a peer in the peer-set.
PeersWithMorePoW(u128)
Peers with more cumulative difficulty than the given cumulative difficulty.
Returned peers will be remembered and won’t be returned from subsequent calls until the guard is dropped.
StemPeer
A random outbound peer.
The returned peer will be remembered and won’t be returned from subsequent calls until the guard is dropped.