pub enum PeerSetResponse<N: NetworkZone> {
MostPoWSeen {
cumulative_difficulty: u128,
height: usize,
top_hash: [u8; 32],
},
PeersWithMorePoW(Vec<ClientDropGuard<N>>),
StemPeer(Option<ClientDropGuard<N>>),
}Expand description
A response from the peer-set.
Variants
MostPoWSeen
Fields
PeersWithMorePoW(Vec<ClientDropGuard<N>>)
PeerSetRequest::PeersWithMorePoW
Returned peers will be remembered and won’t be returned from subsequent calls until the guard is dropped.
StemPeer(Option<ClientDropGuard<N>>)
The returned peer will be remembered and won’t be returned from subsequent calls until the guard is dropped.