pub struct ClientDropGuard<N: NetworkZone> { /* private fields */ }Expand description
A Drop guard for a client returned from the peer-set.
Methods from Deref<Target = Client<N>>
pub fn ready_peer_request(&mut self) -> Ready<'_, Client<Z>, PeerRequest> ⓘ
pub fn ready_peer_request(&mut self) -> Ready<'_, Client<Z>, PeerRequest> ⓘ
Waits for the client to be ready for a [PeerRequest], then returns a service to handle one.
pub fn ready_broadcast(&mut self) -> Ready<'_, Client<Z>, BroadcastMessage> ⓘ
pub fn ready_broadcast(&mut self) -> Ready<'_, Client<Z>, BroadcastMessage> ⓘ
Waits for the client to be ready for a [BroadcastMessage], then returns a service to handle one.