pub struct NetworkInterface<N: NetworkZone> { /* private fields */ }Expand description
The interface to Monero’s P2P network on a certain [NetworkZone].
Implementations
Sourceimpl<N: NetworkZone> NetworkInterface<N>
impl<N: NetworkZone> NetworkInterface<N>
Sourcepub fn broadcast_svc(&self) -> BroadcastSvc<N>
pub fn broadcast_svc(&self) -> BroadcastSvc<N>
Returns a service which allows broadcasting messages to all the connected peers in a specific [NetworkZone].
Sourcepub fn block_downloader<C>(
&self,
our_chain_service: C,
config: BlockDownloaderConfig,
) -> BufferStream<BlockBatch>where
C: Service<ChainSvcRequest<N>, Response = ChainSvcResponse<N>, Error = BoxError> + Send + 'static,
C::Future: Send + 'static,
pub fn block_downloader<C>(
&self,
our_chain_service: C,
config: BlockDownloaderConfig,
) -> BufferStream<BlockBatch>where
C: Service<ChainSvcRequest<N>, Response = ChainSvcResponse<N>, Error = BoxError> + Send + 'static,
C::Future: Send + 'static,
Starts the block downloader and returns a stream that will yield sequentially downloaded blocks.
Sourcepub fn address_book(
&self,
) -> BoxCloneService<AddressBookRequest<N>, AddressBookResponse<N>, BoxError>
pub fn address_book( &self, ) -> BoxCloneService<AddressBookRequest<N>, AddressBookResponse<N>, BoxError>
Returns the address book service.
Sourcepub fn peer_set(
&mut self,
) -> &mut BoxCloneService<PeerSetRequest, PeerSetResponse<N>, BoxError>
pub fn peer_set( &mut self, ) -> &mut BoxCloneService<PeerSetRequest, PeerSetResponse<N>, BoxError>
Borrows the PeerSet, for access to connected peers.