pub enum BroadcastRequest<N: NetworkZone> {
Block {
block_bytes: Bytes,
current_blockchain_height: u64,
},
Transaction {
tx_bytes: Bytes,
direction: Option<ConnectionDirection>,
received_from: Option<InternalPeerID<N::Addr>>,
},
}Expand description
A request to broadcast some data to all connected peers or a sub-set like all inbound or all outbound.
Only certain P2P messages are supported here: [NewFluffyBlock] and [NewTransactions]. These are the only
P2P messages that make sense to broadcast to multiple peers.
NewBlock has been excluded as monerod has had fluffy blocks for a while and
Cuprate sets fluffy blocks as a requirement during handshakes.
Variants
Block
Broadcast a block to the network. The block will be broadcast as a fluffy block to all peers.
Fields
block_bytes: BytesThe block.
Transaction
Broadcast transactions to the network. If a [ConnectionDirection] is set the transaction
will only be broadcast to that sub-set of peers, if it is None then the transaction will
be broadcast to all peers.